@@ -15,69 +15,67 @@ import subprocess
 from datetime import datetime
 from typing import TypeVar, Optional
 
-from PySide2.QtUiTools import QUiLoader
-from PySide2.QtCore import Qt, QTimer, QSize, Signal, QThread, Slot
-from PySide2.QtGui import QPixmap, QIcon, QFontDatabase, QKeySequence
-from PySide2.QtWidgets import QDesktopWidget, QMainWindow, QDialogButtonBox, QPushButton, QLabel, QShortcut
+from PySide6.QtUiTools import QUiLoader
+from PySide6.QtCore import Qt, QTimer, QSize, Signal, QThread, Slot
+from PySide6.QtGui import QPixmap, QIcon, QFontDatabase, QKeySequence, QShortcut
+from PySide6.QtWidgets import QWidget, QMainWindow, QPushButton, QLabel, QCheckBox
 
 from kafka import KafkaProducer, KafkaConsumer
 import ntplib
 
 from .widgets import Montage, Projects, Connection, Records, Annotations
-from .environments import Development, Visualization, StimuliDelivery
+from .environments import Development, Visualization, StimuliDelivery, TimeLockAnalysis
 from .config_manager import ConfigManager
 from .configuration import ConfigurationFrame
-from ..extensions import properties as prop
-from .dialogs import Dialogs
 from .subprocess_handler import run_subprocess
 from .raspad import Raspad
 
-import numpy as np
-
-KAFKA_STREAM = TypeVar('Kafka')
+KafkaMessage = TypeVar('KafkaMessage')
+PathLike = TypeVar('PathLike')
+HostLike = TypeVar('HostLike')
+Millis = TypeVar('Milliseconds')
 
 
 ########################################################################
 class ClockOffset(QThread):
     """"""
-    offset = Signal(object)
+    signal_offset = Signal(object)
 
     # ----------------------------------------------------------------------
-    def set_host(self, host: str) -> None:
+    def set_host(self, host: HostLike) -> None:
         """Set the host for kafka."""
         self.host = host
 
     # ----------------------------------------------------------------------
-    def run(self):
+    def run(self) -> None:
         """"""
         try:
             client = ntplib.NTPClient()
             r = client.request(self.host)
             clock_offset = r.offset  # * 1000
-            self.offset.emit(clock_offset)
+            self.signal_offset.emit(clock_offset)
             print(f'offset: {clock_offset}')
-        except Exception as e:
+        except Exception:
             pass
 
 
 ########################################################################
 class Kafka(QThread):
     """Kafka run on a thread."""
-    on_message = Signal(object)
-    message = Signal()
-    # first_consume = Signal()
-    produser_connected = Signal()
-    continue_ = True
+    signal_kafka_message = Signal(object)
+    signal_exception_message = Signal()
+    signal_produser = Signal()
+    keep_alive = True
 
     # ----------------------------------------------------------------------
-    def set_host(self, host: str) -> None:
+    def set_host(self, host: HostLike) -> None:
         """Set the host for kafka."""
         self.host = host
 
     # ----------------------------------------------------------------------
     def stop(self) -> None:
         """Kill the thread."""
-        self.continue_ = False
+        self.keep_alive = False
         self.terminate()
 
     # ----------------------------------------------------------------------
@@ -85,11 +83,11 @@ class Kafka(QThread):
         """Start the produser and consumer for Kafka."""
         try:
             self.create_produser()
-            self.produser_connected.emit()
+            self.signal_produser.emit()
             self.consumed = False
             self.create_consumer()
-        except Exception as e:
-            self.message.emit()
+        except Exception:
+            self.signal_exception_message.emit()
             self.stop()
 
     # ----------------------------------------------------------------------
@@ -107,14 +105,11 @@ class Kafka(QThread):
         for message in self.consumer:
             self.last_message = datetime.now()
             message.value['timestamp'] = message.timestamp / 1000
-            # if not self.consumed:
-                # self.first_consume.emit()
-                # self.consumed = True
 
-            self.on_message.emit(
+            self.signal_kafka_message.emit(
                 {'topic': message.topic, 'value': message.value})
 
-            if not self.continue_:
+            if not self.keep_alive:
                 return
 
     # ----------------------------------------------------------------------
@@ -148,6 +143,8 @@ class BCIFramework(QMainWindow):
             lambda evt: self.show_interface('Visualizations'))
         self.main.actionStimuli_delivery.triggered.connect(
             lambda evt: self.show_interface('Stimuli_delivery'))
+        self.main.actionTimelock_analysis.triggered.connect(
+            lambda evt: self.show_interface('Timelock_analysis'))
         self.main.actionHome.triggered.connect(
             lambda evt: self.show_interface('Home'))
         self.main.actionDocumentation.triggered.connect(
@@ -155,22 +152,14 @@ class BCIFramework(QMainWindow):
         self.main.actionRaspad_settings.triggered.connect(
             lambda evt: self.show_interface('Raspad_settings'))
 
-        shortcut_fullscreen = QShortcut(QKeySequence('F11'), self.main)
-        shortcut_fullscreen.activated.connect(lambda: self.main.showMaximized(
-        ) if self.main.windowState() & Qt.WindowFullScreen else self.main.showFullScreen())
-
-        shortcut_docs = QShortcut(QKeySequence('F1'), self.main)
-        shortcut_docs.activated.connect(
-            lambda: self.show_interface('Documentation'))
-
-        shortcut_docs = QShortcut(QKeySequence('F2'), self.main)
-        shortcut_docs.activated.connect(self.toggle_dock_collapsed)
+        self.main.stackedWidget_montage.setCurrentWidget(
+            self.main.page_montage)
 
         self.show_interface('Home')
         self.config = ConfigManager()
 
-        for i in range(self.main.toolBar_environs.layout().count()):
-            tool_button = self.main.toolBar_environs.layout().itemAt(i).widget()
+        for i in range(self.main.toolBar_Environs.layout().count()):
+            tool_button = self.main.toolBar_Environs.layout().itemAt(i).widget()
             tool_button.setMaximumWidth(200)
             tool_button.setMinimumWidth(200)
 
@@ -182,11 +171,12 @@ class BCIFramework(QMainWindow):
         self.projects = Projects(self.main, self)
         self.records = Records(self.main, self)
         self.annotations = Annotations(self.main, self)
-        self.raspad = Raspad(self.main, self)
+        self.raspad = Raspad(self)
 
         self.development = Development(self)
         self.visualizations = Visualization(self)
         self.stimuli_delivery = StimuliDelivery(self)
+        self.timelock_analysis = TimeLockAnalysis(self)
 
         # self.status_bar('OpenBCI no connected')
 
@@ -211,11 +201,33 @@ class BCIFramework(QMainWindow):
         self.aux_size = 0
         self.sample_rate = 0
         self.last_update = 0
+
         # QTimer().singleShot(1000, self.calculate_offset)
         QTimer().singleShot(3000, self.start_stimuli_server)
 
         self.status_bar(message='', right_message=('disconnected', None))
 
+        shortcut_fullscreen = QShortcut(QKeySequence('F11'), self.main)
+        shortcut_fullscreen.activated.connect(lambda: self.main.showMaximized(
+        ) if self.main.windowState() & Qt.WindowFullScreen else self.main.showFullScreen())
+
+        shortcut_docs = QShortcut(QKeySequence('F1'), self.main)
+        shortcut_docs.activated.connect(
+            lambda: self.show_interface('Documentation'))
+
+        shortcut_docs = QShortcut(QKeySequence('F2'), self.main)
+        shortcut_docs.activated.connect(self.toggle_dock_collapsed)
+
+        shortcut_docs = QShortcut(QKeySequence('F9'), self.main)
+        shortcut_docs.activated.connect(
+            self.timelock_analysis.show_fullscreen)
+
+        self.main.toolBar_Environs.setStyleSheet("""
+          * {
+          min-width: 200px;
+          }
+          """)
+
     # ----------------------------------------------------------------------
     def set_icons(self) -> None:
         """The Qt resource system has been deprecated."""
@@ -223,8 +235,9 @@ class BCIFramework(QMainWindow):
             return QIcon(f"bci:/primary/{name}.svg")
 
         self.main.actionDevelopment.setIcon(icon("file"))
-        self.main.actionVisualizations.setIcon(icon("brain"))
+        self.main.actionVisualizations.setIcon(icon("latency2"))
         self.main.actionStimuli_delivery.setIcon(icon("imagery"))
+        self.main.actionTimelock_analysis.setIcon(icon("brain"))
         self.main.actionHome.setIcon(icon("home"))
         self.main.actionDocumentation.setIcon(icon("documentation"))
 
@@ -237,8 +250,9 @@ class BCIFramework(QMainWindow):
         self.main.pushButton_brain.setIcon(icon("brain"))
         self.main.pushButton_imagery.setIcon(icon("imagery"))
         self.main.pushButton_docs.setIcon(icon("documentation"))
-        self.main.pushButton_latency.setIcon(icon("latency2"))
+        self.main.pushButton_latency.setIcon(icon("latency"))
         self.main.pushButton_annotations.setIcon(icon("annotation"))
+        self.main.pushButton_timelock.setIcon(icon("latency2"))
 
         self.main.pushButton_stop_preview.setIcon(
             icon('media-playback-stop'))
@@ -335,16 +349,16 @@ class BCIFramework(QMainWindow):
         self.main.dockWidget_global.setMinimumWidth(w)
 
         if not collapsed:
-            self.main.dockWidget_global.setMaximumWidth(9999)
-            self.main.dockWidget_global.setMinimumWidth(100)
+            self.main.dockWidget_global.setMaximumWidth(w * 99)
+            self.main.dockWidget_global.setMinimumWidth(0)
 
     # ----------------------------------------------------------------------
     def toggle_dock_collapsed(self) -> None:
         """"""
-        if self.main.dockWidget_global.maximumWidth() >= 9999:
-            self.set_dock_collapsed(True)
-        else:
+        if self.main.dockWidget_global.maximumWidth() < 100:
             self.set_dock_collapsed(False)
+        else:
+            self.set_dock_collapsed(True)
 
     # ----------------------------------------------------------------------
     def connect(self) -> None:
@@ -359,6 +373,8 @@ class BCIFramework(QMainWindow):
             lambda evt: self.show_interface('Visualizations'))
         self.main.pushButton_show_stimuli_delivery.clicked.connect(
             lambda evt: self.show_interface('Stimuli_delivery', 0))
+        self.main.pushButton_show_timelock.clicked.connect(
+            lambda evt: self.show_interface('Timelock_analysis', 0))
 
         self.main.pushButton_show_documentation.clicked.connect(
             lambda evt: self.show_interface('Documentation'))
@@ -390,13 +406,13 @@ class BCIFramework(QMainWindow):
             lambda b: self.board_handle(self.main.checkBox_board4, b))
 
     # ----------------------------------------------------------------------
-    def board_handle(self, chbox, b):
+    def board_handle(self, chbox: QCheckBox, enable: bool) -> None:
         """"""
-        chbox.setEnabled(b)
+        chbox.setEnabled(enable)
         chbox.setChecked(False)
 
     # ----------------------------------------------------------------------
-    def open_folder_in_system(self, path) -> None:
+    def open_folder_in_system(self, path: PathLike) -> None:
         """"""
         if platform.system() == "Windows":
             os.startfile(path)
@@ -410,7 +426,7 @@ class BCIFramework(QMainWindow):
         """Switch between environs."""
         self.main.stackedWidget_modes.setCurrentWidget(
             getattr(self.main, f"page{interface}"))
-        for action in self.main.toolBar_environs.actions():
+        for action in self.main.toolBar_Environs.actions():
             action.setChecked(False)
         for action in self.main.toolBar_Documentation.actions():
             action.setChecked(False)
@@ -441,7 +457,6 @@ class BCIFramework(QMainWindow):
         *{
         font-weight: normal;
         font-family: 'DejaVu Sans Mono';
-        font-size: 13px;
         }
         """)
 
@@ -459,7 +474,7 @@ class BCIFramework(QMainWindow):
         # item.widget().deleteLater()
 
     # ----------------------------------------------------------------------
-    def status_bar(self, message: str = None, right_message: str = None) -> None:
+    def status_bar(self, message: Optional[str] = None, right_message: Optional[str] = None) -> None:
         """Update messages for status bar."""
         statusbar = self.main.statusBar()
 
@@ -536,6 +551,7 @@ class BCIFramework(QMainWindow):
         self.main.pushButton_docs.setStyleSheet(style)
         self.main.pushButton_latency.setStyleSheet(style)
         self.main.pushButton_annotations.setStyleSheet(style)
+        self.main.pushButton_timelock.setStyleSheet(style)
 
         style = f"""
         QFrame {{
@@ -547,31 +563,30 @@ class BCIFramework(QMainWindow):
         self.main.frame_5.setStyleSheet(style)
         self.main.frame_6.setStyleSheet(style)
         self.main.frame_7.setStyleSheet(style)
+        self.main.frame_4.setStyleSheet(style)
         self.main.frame.setStyleSheet(style)
 
         style = """
         *{
-        font-family: "Roboto Light";
-        font-weight: 300;
+        color: black;
         }
         """
 
+        # FONTSIZE
         labels = [self.main.label_15, self.main.label_16, self.main.label_17,
-                  self.main.label_20, self.main.label_21, self.main.label_22, ]
-
+                  self.main.label_20, self.main.label_21, self.main.label_22,
+                  self.main.label_23]
         for label in labels:
-            label.setStyleSheet(style)
-
             if json.loads(os.getenv('BCISTREAM_RASPAD')):
                 label.setText(label.text().replace(
                     'font-size:12pt', 'font-size:10pt'))
 
         with open(os.path.join(os.environ['BCISTREAM_ROOT'], '_version.txt'), 'r') as file:
             self.main.label_software_version.setText(
-                f'{file.read()} {version} {mode}')
+                f'{file.read().strip()} {version} {mode}')
 
     # ----------------------------------------------------------------------
-    def show_about(self, event=None) -> None:
+    def show_about(self, *args, **wargs) -> None:
         """Display about window."""
         frame = os.path.join(
             os.environ['BCISTREAM_ROOT'], 'framework', 'qtgui', 'about.ui')
@@ -602,7 +617,7 @@ class BCIFramework(QMainWindow):
         }}
         """)
 
-        center = QDesktopWidget().availableGeometry().center()
+        center = QWidget.screen(self).availableGeometry().center()
         geometry = about.frameGeometry()
         geometry.moveCenter(center)
         about.move(geometry.topLeft())
@@ -611,7 +626,7 @@ class BCIFramework(QMainWindow):
 
     # ----------------------------------------------------------------------
     @Slot()
-    def on_kafka_event(self, value: KAFKA_STREAM) -> None:
+    def on_kafka_event(self, value: KafkaMessage) -> None:
         """Register annotations and markers."""
 
         self.streaming = True
@@ -661,18 +676,19 @@ class BCIFramework(QMainWindow):
             # self.last_update = value['value']['timestamp']
 
     # ----------------------------------------------------------------------
-    def update_kafka(self, host) -> None:
+    def update_kafka(self, host: HostLike) -> None:
         """Try to restart kafka services."""
         if hasattr(self, 'thread_kafka'):
             self.thread_kafka.stop()
             self.status_bar(right_message=('No streaming', False))
         # try:
         self.thread_kafka = Kafka()
-        self.thread_kafka.on_message.connect(self.on_kafka_event)
+        self.thread_kafka.signal_kafka_message.connect(self.on_kafka_event)
         # self.thread_kafka.first_consume.connect(lambda: self.connection.on_connect(
             # True))
-        self.thread_kafka.message.connect(self.kafka_message)
-        self.thread_kafka.produser_connected.connect(
+        self.thread_kafka.signal_exception_message.connect(
+            self.kafka_message)
+        self.thread_kafka.signal_produser.connect(
             self.kafka_produser_connected)
         self.thread_kafka.set_host(host)
         self.thread_kafka.start()
@@ -683,19 +699,19 @@ class BCIFramework(QMainWindow):
         self.timer.start()
 
     # ----------------------------------------------------------------------
-    def calculate_offset(self):
+    def calculate_offset(self) -> None:
         """"""
         host = self.thread_kafka.host
         if host != 'localhost':
             self.offset_thread = ClockOffset()
-            self.offset_thread.offset.connect(self.set_offset)
+            self.offset_thread.signal_offset.connect(self.set_offset)
             self.offset_thread.set_host(self.thread_kafka.host)
             self.offset_thread.start()
         else:
             self.set_offset(0)
 
     # ----------------------------------------------------------------------
-    def set_offset(self, offset):
+    def set_offset(self, offset: Millis) -> None:
         """"""
         os.environ['BCISTREAM_OFFSET'] = json.dumps(offset)
 
@@ -722,7 +738,7 @@ class BCIFramework(QMainWindow):
                 self.main.pushButton_record.setEnabled(True)
 
     # ----------------------------------------------------------------------
-    @ Slot()
+    @Slot()
     def kafka_message(self) -> None:
         """Error on kafka."""
         self.streaming = False
@@ -734,7 +750,7 @@ class BCIFramework(QMainWindow):
         self.status_bar(right_message=('Disconnected', None))
 
     # ----------------------------------------------------------------------
-    @ Slot()
+    @Slot()
     def kafka_produser_connected(self) -> None:
         """If produser connected is posible the consumer too."""
         self.status_bar(right_message=('Connected', False))
@@ -746,18 +762,18 @@ class BCIFramework(QMainWindow):
         configuration.show()
 
     # ----------------------------------------------------------------------
-    def handle_feedback(self, data):
+    def handle_feedback(self, data) -> None:
         """"""
         if fn := getattr(self, f"feedback_{data['name']}", False):
             fn(data['value'])
 
     # ----------------------------------------------------------------------
-    def feedback_set_latency(self, value):
+    def feedback_set_latency(self, latency: Millis) -> None:
         """"""
-        os.environ['BCISTREAM_SYNCLATENCY'] = json.dumps(value)
+        os.environ['BCISTREAM_SYNCLATENCY'] = json.dumps(latency)
 
     # ----------------------------------------------------------------------
-    def start_stimuli_server(self):
+    def start_stimuli_server(self) -> None:
         """"""
         if '--local' in sys.argv:
             self.bciframework_server = run_subprocess([sys.executable, os.path.join(
